@@ -84,9 +84,9 @@ def run() -> None:
             force = False
         if len(sys.argv) <= 1:
             sys.exit(run_help)
-        elif '-h' in sys.argv or '--help' in sys.argv or re.findall(r"^-h", sys.argv[1]):
+        elif '-h' in sys.argv or '--help' in sys.argv or re.findall(r"^-h[f]*$", sys.argv[1]):
             print(run_help)
-        elif '-s' in sys.argv or '--status' in sys.argv or re.findall(r"^-s", sys.argv[1]):
+        elif '-s' in sys.argv or '--status' in sys.argv or re.findall(r"^-s[f]*$", sys.argv[1]):
             print_status(database, default_hosts, __version__)
         elif '-v' in sys.argv or '--version' in sys.argv or re.findall(r"^-v", sys.argv[1]):
             print(version_info)
@@ -103,7 +103,7 @@ def run() -> None:
                 else:
                     with sqlite3.connect(database) as db:
                         update_hosts(hosts, db, default_hosts, default_ip, force=True)
-            elif re.match(r"^-a", sys.argv[1]):
+            elif re.match(r"^-a[f]*$", sys.argv[1]):
                 check_root()
                 if 'f' in sys.argv[1]:
                     force = True
@@ -127,7 +127,7 @@ def run() -> None:
                 else:
                     with sqlite3.connect(database) as db:
                         update_hosts(hosts, db, default_hosts, default_ip, force=True)
-            elif re.match(r"^-b", sys.argv[1]):
+            elif re.match(r"^-b[f]*$", sys.argv[1]):
                 check_root()
                 if 'f' in sys.argv[1]:
                     force = True
@@ -152,7 +152,7 @@ def run() -> None:
                 else:
                     with sqlite3.connect(database) as db:
                         update_hosts(hosts, db, default_hosts, default_ip, force=True)
-            elif re.match(r"^-r", sys.argv[1]):
+            elif re.match(r"^-r[f]*$", sys.argv[1]):
                 check_root()
                 if 'f' in sys.argv[1]:
                     force = True
@@ -177,7 +177,7 @@ def run() -> None:
                 else:
                     with sqlite3.connect(database) as db:
                         update_hosts(hosts, db, default_hosts, default_ip, force=True)
-            elif re.match(r"^-d", sys.argv[1]):
+            elif re.match(r"^-d[f]*", sys.argv[1]):
                 check_root()
                 if 'f' in sys.argv[1]:
                     force = True
@@ -200,7 +200,7 @@ def run() -> None:
                 else:
                     user = False
                 list_rules(database, standard=standard, user=user)
-            elif re.match(r"^-l", sys.argv[1]):
+            elif re.match(r"^-l[fsu]*$", sys.argv[1]):
                 if '-s' in sys.argv or '--standard' in sys.argv or 's' in sys.argv[1]:
                     standard = True
                 else:
@@ -240,7 +240,7 @@ def run() -> None:
                 if '-y' in sys.argv or '--sync' in sys.argv:
                     update_remote_repo(remote_repo, remote_repo_mirror, remote_repo_version_db, database,
                                        tmp_dir, force=force)
-            elif re.match(r"^-S", sys.argv[1]):
+            elif re.match(r"^-S[cymf]*$", sys.argv[1]):
                 check_root()
                 if 'f' in sys.argv[1]:
                     force = True
@@ -292,7 +292,7 @@ def run() -> None:
                 if '-y' in sys.argv or '--sync' in sys.argv:
                     update_remote_repo(remote_repo, remote_repo_mirror, remote_repo_version_db, database,
                                        tmp_dir, force=force)
-            elif re.match(r"^-R", sys.argv[1]):
+            elif re.match(r"^-R[fy]*$", sys.argv[1]):
                 check_root()
                 if 'f' in sys.argv[1]:
                     force = True
@@ -321,7 +321,7 @@ def run() -> None:
                 if '-y' in sys.argv or '--sync' in sys.argv:
                     update_remote_repo(remote_repo, remote_repo_mirror, remote_repo_version_db, database,
                                        tmp_dir, force=force)
-            elif re.match(r"^-U", sys.argv[1]):
+            elif re.match(r"^-U[yf]*$", sys.argv[1]):
                 check_root()
                 if 'f' in sys.argv[1]:
                     force = True
@@ -358,7 +358,7 @@ def run() -> None:
                 if '-y' in sys.argv or '--sync' in sys.argv:
                     update_remote_repo(remote_repo, remote_repo_mirror, remote_repo_version_db, database,
                                        tmp_dir, force=force)
-            elif re.match(r"^-M", sys.argv[1]):
+            elif re.match(r"^-M[fy]*$", sys.argv[1]):
                 check_root()
                 if 'f' in sys.argv[1]:
                     force = True
@@ -389,7 +389,7 @@ def run() -> None:
                         count += 1
                 if count == 0:
                     sys.exit('Error: please specify at least one filter ID')
-            elif re.match(r"^-I", sys.argv[1]):
+            elif re.match(r"^-I[f]*$", sys.argv[1]):
                 for arg in sys.argv[1:]:
                     if not re.findall(r"^-[0-9a-zA-Z\-]", arg):
                         show_filter_info(arg, database)
@@ -415,7 +415,7 @@ def run() -> None:
                     available = False
                 list_filters(database, custom=custom, subscribed=subscribed, unsubscribed=unsubscribed,
                              available=available)
-            elif re.match(r"^-L", sys.argv[1]):
+            elif re.match(r"^-L[csnwf]*$", sys.argv[1]):
                 if '--custom' in sys.argv or '-c' in sys.argv or 'c' in sys.argv[1]:
                     custom = True
                 else:
@@ -438,7 +438,7 @@ def run() -> None:
                 check_root()
                 update_remote_repo(remote_repo, remote_repo_mirror, remote_repo_version_db, database, tmp_dir,
                                    force=force)
-            elif re.match(r"^-Y", sys.argv[1]):
+            elif re.match(r"^-Y[f]*$", sys.argv[1]):
                 check_root()
                 if 'f' in sys.argv[1]:
                     force = True
@@ -448,7 +448,7 @@ def run() -> None:
                 check_root()
                 with sqlite3.connect(database) as db:
                     update_hosts(hosts, db, default_hosts, default_ip, force=force)
-            elif re.match(r"^-H", sys.argv[1]):
+            elif re.match(r"^-H[f]*$", sys.argv[1]):
                 check_root()
                 if 'f' in sys.argv[1]:
                     force = True
@@ -457,7 +457,7 @@ def run() -> None:
             elif sys.argv[1] == '--restore':
                 check_root()
                 restore_hosts(hosts, default_hosts, force=force)
-            elif re.match(r"^-D", sys.argv[1]):
+            elif re.match(r"^-D[f]*", sys.argv[1]):
                 check_root()
                 if 'f' in sys.argv[1]:
                     force = True
@@ -475,9 +475,9 @@ def run_converter() -> None:
     try:
         if len(sys.argv) <= 1:
             sys.exit(run_converter_help)
-        elif '-h' in sys.argv or '--help' in sys.argv or re.findall(r"^-h", sys.argv[1]):
+        elif '-h' in sys.argv or '--help' in sys.argv or re.match(r"^-h", sys.argv[1]):
             print(run_converter_help)
-        elif '-v' in sys.argv or '--version' in sys.argv or re.findall(r"^-v", sys.argv[1]):
+        elif '-v' in sys.argv or '--version' in sys.argv or re.match(r"^-v", sys.argv[1]):
             print(version_info.replace(
                 'TBlock',
                 'TBlockc'
@@ -486,14 +486,14 @@ def run_converter() -> None:
                 'TBlock\'s built-in filter converter'
             ))
         else:
-            if '-f' in sys.argv or '--force' in sys.argv or re.findall(r"^-.*f", sys.argv[1]):
+            if '-f' in sys.argv or '--force' in sys.argv or re.match(r"^-.*f", sys.argv[1]):
                 force = True
             else:
                 force = False
-            if '-g' in sys.argv or '--get-syntax' in sys.argv or re.findall(r"^-g", sys.argv[1]):
+            if '-g' in sys.argv or '--get-syntax' in sys.argv or re.match(r"^-g", sys.argv[1]):
                 file_to_scan = None
                 for arg in sys.argv[1:]:
-                    if not re.findall(r"^-[0-9a-zA-Z\-]", arg) and not arg == file_to_scan:
+                    if not re.match(r"^-[0-9a-zA-Z\-]", arg) and not arg == file_to_scan:
                         file_to_scan = arg
                         break
                 if file_to_scan is None:
@@ -540,7 +540,7 @@ def run_converter() -> None:
                 if '-c' in sys.argv or '--comments' in sys.argv or re.findall(r"^-.*c", sys.argv[1]):
                     comments = True
                 for arg in sys.argv[1:]:
-                    if not re.findall(r"^-[0-9a-zA-Z\-]", arg) and not arg == input_file and not arg == output_file and \
+                    if not re.match(r"^-[0-9a-zA-Z\-]", arg) and not arg == input_file and not arg == output_file and \
                             not arg == permissions and not arg == syntax and not arg == original_syntax:
                         if input_file is None:
                             input_file = arg
