@@ -21,6 +21,7 @@
 
 # Standard libraries
 import os
+import sys
 import sqlite3
 
 
@@ -36,7 +37,8 @@ def setup_database(db_path: str) -> None:
             "policy"	TEXT NOT NULL,
             "filter_id"	TEXT NOT NULL,
             "priority"	INTEGER NOT NULL,
-            "ip"	TEXT
+            "ip"	TEXT,
+            PRIMARY KEY("domain")
         );''')
         db.cursor().execute('''CREATE TABLE IF NOT EXISTS "filters" (
             "id"	TEXT NOT NULL UNIQUE,
@@ -44,7 +46,8 @@ def setup_database(db_path: str) -> None:
             "metadata"	TEXT NOT NULL,
             "subscribing"	INTEGER NOT NULL,
             "on_rfr"	INTEGER NOT NULL,
-            "permissions"   TEXT
+            "permissions"   TEXT,
+            PRIMARY KEY("id")
         );''')
         db.commit()
 
@@ -60,9 +63,14 @@ default_ip = '127.0.0.1'
 if os.path.isdir('/data/data/com.termux/files/usr'):
     tmp_dir = os.path.join('/data/data/com.termux/files/usr/tmp', 'tblock')
     lib_dir = os.path.join('/data/data/com.termux/files/usr/lib', 'tblock')
-else:
+elif os.path.isdir('/var/lib/tblock/') and os.path.isdir('/tmp/tblock/'):
     lib_dir = '/var/lib/tblock/'
     tmp_dir = '/tmp/tblock/'
+else:
+    sys.exit(
+        'Error: TBlock does not seem to support your OS.\n'
+        'If this seems to be a bug, you can report it at: https://codeberg.org/tblock/tblock/issues'
+    )
 
 database = os.path.join(lib_dir, 'storage.sqlite')
 remote_repo_version_db = os.path.join(lib_dir, 'repo')
