@@ -530,9 +530,9 @@ def update_hosts(hosts_path: str, db: sqlite3.Connection, default_hosts: str, de
     for domain in all_rules:
         if verbosity:
             if count < len(all_rules):
-                print(f' => Retrieving rules... ({count}/{len(all_rules)})', end='\r')
+                print(f' ==> Retrieving rules... ({count}/{len(all_rules)})', end='\r')
             else:
-                print(f' => Retrieved all rules ({count}/{len(all_rules)})')
+                print(f' ==> Retrieved all rules ({count}/{len(all_rules)})')
         if all_rules[domain]['policy'] == Policy.block:
             new_hosts += f'{default_ip}    {domain}\n'
         elif all_rules[domain]['policy'] == Policy.redirect:
@@ -544,7 +544,7 @@ def update_hosts(hosts_path: str, db: sqlite3.Connection, default_hosts: str, de
         with open(default_hosts, 'wt') as h:
             h.write(default_hosts_content)
         if verbosity:
-            print(' => Backed up previous hosts file')
+            print(' ==> Backed up previous hosts file')
     else:
         with open(default_hosts, 'rt') as h:
             default_hosts_content = h.read()
@@ -556,9 +556,9 @@ def update_hosts(hosts_path: str, db: sqlite3.Connection, default_hosts: str, de
             'overwritten.\n\n' + new_hosts
         )
     if not was_enabled:
-        print(f' => {Fore.GREEN}Protection is now enabled{Style.RESET_ALL}')
+        print(f' ==> {Fore.GREEN}Protection is now enabled{Style.RESET_ALL}')
     if verbosity:
-        print(' => Hosts file updated')
+        print(' ==> Hosts file updated')
 
 
 def restore_hosts(hosts_path: str, default_hosts: str,
@@ -584,11 +584,11 @@ def restore_hosts(hosts_path: str, default_hosts: str,
     with open(hosts_path, 'wt') as f:
         f.write(default_hosts_content)
     if verbosity:
-        print(' => Default hosts file restored')
+        print(' ==> Default hosts file restored')
     os.remove(default_hosts)
     if verbosity:
-        print(' => Removed default hosts backup')
+        print(' ==> Removed default hosts backup')
     if verbosity:
-        print(f' => {Fore.RED}Protection is now disabled{Style.RESET_ALL}')
+        print(f' ==> {Fore.RED}Protection is now disabled{Style.RESET_ALL}')
         print("You can now safely edit your hosts file manually.\n"
               "After that, run 'tblock -H' to update this file while keeping your modifications.")
