@@ -86,11 +86,11 @@ def subscribe_to_filter(filter_id: str, db_path: str, tmp_dir: str, permissions:
             if new_filter.exists:
                 new_filter.subscribe(permissions)
                 if verbosity:
-                    print(' => Marked already existing filter as subscribed in database')
+                    print(' ==> Marked already existing filter as subscribed in database')
             else:
                 new_filter.subscribe(permissions, source)
                 if verbosity:
-                    print(' => Added new custom filter into database')
+                    print(' ==> Added new custom filter into database')
             db.close()
             update_filter(filter_id, db_path, tmp_dir, verbosity, force=True)
         else:
@@ -128,16 +128,16 @@ def unsubscribe_to_filter(filter_id: str, db_path: str, verbosity: bool = True,
             if verbosity:
                 print(f':: Unsubscribing to filter: {filter_id}')
             if verbosity:
-                print(' => Removing all filters rules ...', end='\r')
+                print(' ==> Removing all filters rules ...', end='\r')
             new_filter.remove_all_rules()
             if verbosity:
-                print(' => Removing all filters rules: done')
+                print(' ==> Removing all filters rules: done')
             new_filter.unsubscribe()
             if verbosity:
                 if new_filter.on_rfr:
-                    print(' => Marked filter as unsubscribed in database')
+                    print(' ==> Marked filter as unsubscribed in database')
                 else:
-                    print(' => Removed custom filter from database')
+                    print(' ==> Removed custom filter from database')
                 print('All rules from filter have been removed. However, it is recommended to run "tblock -U" to update'
                       ' rules from all other filters.')
             db.close()
@@ -181,7 +181,7 @@ def update_filter(filter_id: str, db_path: str, tmp_dir: str, verbosity: bool =
     else:
         if verbosity:
             print(f':: Updating filter: {filter_id}')
-            print(f' => Get source: {new_filter.source}')
+            print(f' ==> Get source: {new_filter.source}')
         if is_url(new_filter.source):
             tmp_filter = os.path.join(tmp_dir, generate_tmp_filename())
             try:
@@ -189,8 +189,8 @@ def update_filter(filter_id: str, db_path: str, tmp_dir: str, verbosity: bool =
             except (requests.exceptions.ConnectionError, urllib3.exceptions.MaxRetryError, ConnectionRefusedError,
                     urllib3.exceptions.NewConnectionError):
                 if verbosity:
-                    print(' => Failed to get source')
-                    print(f' => Failed to update filter: {filter_id}')
+                    print(' ==> Failed to get source')
+                    print(f' ==> Failed to update filter: {filter_id}')
                 db.close()
                 sys.exit(1)
         else:
@@ -208,10 +208,10 @@ def update_filter(filter_id: str, db_path: str, tmp_dir: str, verbosity: bool =
                 print(f'Error: syntax of filter {filter_id} is not supported')
                 sys.exit(1)
         if verbosity:
-            print(' => Removing all previous filter rules ...', end='\r')
+            print(' ==> Removing all previous filter rules ...', end='\r')
         Filter(filter_id, db).remove_all_rules()
         if verbosity:
-            print(' => Removing all previous rules from filter: done')
+            print(' ==> Removing all previous rules from filter: done')
         # Only remove local filter if filter has been downloaded, not if it is a local file
         if new_filter.source != tmp_filter:
             os.remove(tmp_filter)
@@ -222,9 +222,9 @@ def update_filter(filter_id: str, db_path: str, tmp_dir: str, verbosity: bool =
         for rule in all_rules:
             if verbosity:
                 if count < len(all_rules.keys()):
-                    print(f' => Adding new rules to database... ({count}/{all_rules_count})', end='\r')
+                    print(f' ==> Adding new rules to database... ({count}/{all_rules_count})', end='\r')
                 else:
-                    print(f' => Added all new rules from filter into database ({count}/{all_rules_count})')
+                    print(f' ==> Added all new rules from filter into database ({count}/{all_rules_count})')
             if rule in all_rules_in_db and all_rules_in_db[rule]['priority']:
                 pass
             elif all_rules[rule][0] == Policy.allow and allow or all_rules[rule][0] == Policy.block and block:
@@ -347,33 +347,33 @@ def update_remote_repo(repo_url: str, repo_mirror: list, version_file: str,
         sys.exit()
     if verbosity:
         print(':: Updating remote repository')
-        print(f' => Get index: {repo_url}')
+        print(f' ==> Get index: {repo_url}')
     try:
         download_file(repo_url, tmp_index)
     except (requests.exceptions.ConnectionError, urllib3.exceptions.MaxRetryError, ConnectionRefusedError,
             urllib3.exceptions.NewConnectionError):
         if verbosity:
-            print(' => Failed to get index')
+            print(' ==> Failed to get index')
         for mirror in repo_mirror:
             try:
                 if verbosity:
-                    print(f' => Get mirror: {mirror}')
+                    print(f' ==> Get mirror: {mirror}')
                 download_file(mirror, tmp_index)
             except (requests.exceptions.ConnectionError, urllib3.exceptions.MaxRetryError, ConnectionRefusedError,
                     urllib3.exceptions.NewConnectionError):
                 if verbosity:
-                    print(f' => Failed to get mirror: {mirror}')
+                    print(' ==> Failed to get mirror')
                 if repo_mirror.index(mirror) == len(repo_mirror) - 1:
                     if verbosity:
-                        print(' => Failed to update remote repository')
+                        print(' ==> Failed to update remote repository')
                     db.close()
                     sys.exit(1)
     try:
         data = ElementTree.parse(tmp_index).getroot()
     except ElementTree.ParseError:
         if verbosity:
-            print(' => Repository seems invalid')
-            print(' => Failed to update remote repository')
+            print(' ==> Downloaded repository seems invalid')
+            print(' ==> Failed to update remote repository')
         db.close()
         sys.exit(1)
     if os.path.isfile(os.path.realpath(version_file)):
@@ -384,10 +384,10 @@ def update_remote_repo(repo_url: str, repo_mirror: list, version_file: str,
     if data.tag == 'repository':
         if current_version == int(data.attrib['version']) and not force:
             if verbosity:
-                print(' => Remote repository is up-to-date')
+                print(' ==> Remote repository is up-to-date')
         else:
             if verbosity:
-                print(f' => Upgrading repository version {data.attrib["version"]} over {str(current_version)}')
+                print(f' ==> Upgrading repository version {data.attrib["version"]} over {str(current_version)}')
             with open(os.path.realpath(version_file), 'wt') as f:
                 f.write(data.attrib["version"])
             all_filters = []
@@ -396,9 +396,9 @@ def update_remote_repo(repo_url: str, repo_mirror: list, version_file: str,
                 all_filters.append(_filter.attrib['id'])
             for _filter in data:
                 if count < len(all_filters) and verbosity:
-                    print(f' => Updating filters ({count}/{len(all_filters)})', end='\r')
+                    print(f' ==> Updating filters ({count}/{len(all_filters)})', end='\r')
                 elif verbosity:
-                    print(f' => Updating filters ({count}/{len(all_filters)})')
+                    print(f' ==> Updating filters ({count}/{len(all_filters)})')
                 metadata = {
                     "title": None,
                     "description": None,
